@@ -32,7 +32,7 @@ OPERATOR_LIST = [
         (' ([+',    '+',    '+])= ',        '(\+\+\w)|(\w\+\+)'),
         (' ([-',    '-',    '-])=> ',       '(--\w)|(\w--)'),
         (' ([/*',   '*',    ':NOTHING:',    '[\[\{\( ]\*{2,}'),
-        (' (/*',    '/',    '*/= ',         '<\w+?\/\w+?\.h>'),
+        (' (/*',    '/',    '*/= ',         '(<.*?\/.*?\.h>)|(".*?\/.*?\.h")'),
         ('< ',      '<',    ':ALL:'),
         (':ALL:',   '>',    ' >='),
         (' ',       '&',    ':ALL:'),
